//
// Simple passthrough vertex shader
//
attribute vec3 in_Position;                  // (x,y,z)
//attribute vec3 in_Normal;                  // (x,y,z)     unused in this shader.	
attribute vec4 in_Colour;                    // (r,g,b,a)
attribute vec2 in_TextureCoord;              // (u,v)

varying vec2 v_vTexcoord;
varying vec4 v_vColour;

void main()
{
    vec4 object_space_pos = vec4( in_Position.x, in_Position.y, in_Position.z, 1.0);
    gl_Position = gm_Matrices[MATRIX_WORLD_VIEW_PROJECTION] * object_space_pos;
    
    v_vColour = in_Colour;
    v_vTexcoord = in_TextureCoord;
}

//######################_==_YOYO_SHADER_MARKER_==_######################@~/*
Pretty simple fragment shader

This shader takes an alpha_map and applies it to whatever is drawn
(or something along those lines)

If the brightness of the alpha_channel pixel is larger than .6
Then the corresponding pixel in whatever is drawn will be visible
else
The corresponding pixel will be invisible

You can play around with the .6, but I think it works best
(And my opinion is obviously always the best opinion)

If you're remotely familiar with shaders this should be
pretty straightforward
*/

varying vec2 v_vTexcoord;
varying vec4 v_vColour;

uniform sampler2D alpha_map; //This will hold the black and white "alpha channel"
vec4 alpha_color;

void main()
{
    gl_FragColor = v_vColour * texture2D( gm_BaseTexture, v_vTexcoord );
    alpha_color =  texture2D(alpha_map, v_vTexcoord );
    
    /*
    if the average of the R G and B
    of the alpha_map pixel are larger than .6
    then the gl_FragColor pixel (the pixel that's drawn) will be 1.0
    else
    the gl_FragColor pixel will be 0.0
    (don't forget to put those .0's on your floats kids!)
    */    
    if ((alpha_color.r+alpha_color.g+alpha_color.b)/3.0 > .6)
    {
    gl_FragColor.a = 1.0;        
    }
    else
    {
    gl_FragColor.a = 0.0;
    }
}
//Believe in yourself and achieve your dreams!
